@@ -275,6 +275,7 @@ rpc_callfilter(char *data, u_int length, ipaddrt src, struct timeval *tstamp)
 {
 	struct rpc_msg *msg = (struct rpc_msg *) data;
 	uint32_t prog = ntohl(msg->rm_call.cb_prog);
+	static int warned = 0;
 
 	/*
 	 * Decide what to do based on the program.
@@ -286,8 +287,13 @@ rpc_callfilter(char *data, u_int length, ipaddrt src, struct timeval *tstamp)
 			nfs_filter(data, length, src, tstamp);
 		else if (version == 3)
 			nfs3_filter(data, length, src, tstamp);
-		else
-			fprintf(stderr, "Unknown NFS version: %d\n", version);
+		else {
+			if (!warned) {
+				fprintf(stderr, "Unknown NFS version: %d\n", version);
+				fprintf(stderr, " - this warning will only be shown once - nfswatch is unable to monitor this version of NFS\n");
+				warned = 1;
+			}
+		}
 		break;
 	}
 	case RPC_PMAPPROG:
